# Jamaisvu-python


## Table of contents
1. [Notice](#notice)
2. [How to install jamaisvu for Python](#how_to_install)
3. [License](#license)
4. [Todo](#todo)
5. [Reference](#ref)


## 1. Notice <a name="notice"></a>
- A collection of useful classes and functions based on the Python3 for deep learning research and development
- I recommend that you should ignore the commented instructions with an octothorpe, #.


## 2. How to install jamaisvu for Python <a name="how_to_install"></a>
### 1. How to install jamaisvu using pip3 from the PyPI
```bash
$ pip3 install jamaisvu
```

### 2. How to install jamaisvu using pip3 from the GitHub repository
```bash
$ pip3 install git+https://github.com/vujadeyoon/jamaisvu-python@${name_tag}
```

### 3. How to install vujade using pip3 from local repository
```bash
$ git clone https://github.com/vujadeyoon/jamaisvu-python && pip3 install -e ./jamaisvu-python
```


## 3. License <a name="license"></a>
- I respect and follow the license of the used libraries including python3 packages.
- The libraries including python3 packages are licensed by their licenses.
- Please note that the only providen vujadeyoon's own codes and wrapper-codes comply with the MIT license.


## 4. Todo <a name="todo"></a>


## 5. Reference <a name="ref"></a>
